@@ -41,8 +41,7 @@ import xml.etree.ElementTree
 from datetime import datetime
 from typing import Optional, Union
 
-localedir = '.'
-translate = gettext.translation('Annotations2Sub', localedir, fallback=True)
+translate = gettext.translation('Annotations2Sub', 'translations', fallback=True)
 _ = translate.gettext
 
 # 应该用无衬线字体,但是好像不能方便的使用字体家族..
@@ -931,7 +930,7 @@ class Annotations2Sub:
             return file + ".ass"
 
 
-if __name__ == "__main__":
+def main():
     parser = argparse.ArgumentParser(description=_("一个可以把Youtube注释转换成ASS字幕的脚本"))
     parser.add_argument(
         "File", type=str, nargs="+", metavar="File or videoId", help=_("待转换的文件")
@@ -1023,3 +1022,6 @@ if __name__ == "__main__":
             sub = Annotations2Sub(file=File, convert_parameter=convert_parameter)
             File = sub.Save(file=File)
             del sub
+
+if __name__ == "__main__":
+    main()
